@@ -1,7 +1,7 @@
 package App::LintPrereqs;
 
 our $DATE = '2016-12-27'; # DATE
-our $VERSION = '0.49'; # VERSION
+our $VERSION = '0.50'; # VERSION
 
 use 5.010001;
 use strict;
@@ -296,6 +296,7 @@ sub lint_prereqs {
     my %mods_from_ini;
     my %assume_used;
     my %assume_provided;
+    my %extrarels;
     for my $section ($cfg->list_sections) {
         $section =~ m!^(
                           osprereqs \s*/\s* .+ |
@@ -331,12 +332,21 @@ sub lint_prereqs {
             if ($phase eq 'Develop' && $rel eq 'Suggests') {
                 # strip extra relationship information in prefix, e.g. _SPEC::, _EMBED::
                 my $extrarel;
-                if ($mod =~ s/\A(_[A-Z]+):://) {
+                if ($mod =~ s/\A(_[A-Z]+::)//) {
                     $extrarel = $1;
                 }
-                if (defined $extrarel && $extrarel !~ /\A(_EMBED)\z/) {
-                    next;
+                if (defined $extrarel) {
+                    if ($extrarel eq '_EMBED::') {
+                        #
+                    } elsif ($extrarel eq '_SPEC::') {
+                        $assume_used{$phase}{$mod} = $v;
+                    } elsif ($extrarel eq '_COPYPASTE') {
+                        $assume_used{$phase}{$mod} = $v;
+                    } else {
+                        return [412, "Unknown extra relationship prefix $extrarel"];
+                    }
                 }
+                $extrarels{$mod} = $extrarel;
             }
 
             $mods_from_ini{$phase}{$mod}   = $v unless $section =~ /assume-provided/;
@@ -438,6 +448,7 @@ sub lint_prereqs {
         for my $mod (keys %{$mods_from_ini{Any}}) {
             my $v = $mods_from_ini{Any}{$mod};
             next if $mod eq 'perl';
+            my $mod0 = ($extrarels{$mod} // '') . $mod;
             $log->tracef("Checking mod from dist.ini: %s (%s)", $mod, $v);
             my $is_core = Module::CoreList::More->is_still_core($mod, $v, $perlv);
             if (!$args{core_prereqs} && $is_core) {
@@ -449,7 +460,7 @@ sub lint_prereqs {
                         "mentioned in dist.ini",
                     remedy  => "Remove from dist.ini",
                     remedy_cmds => [
-                        ["pdrutil", "remove-prereq", $mod],
+                        ["pdrutil", "remove-prereq", $mod0],
                     ],
                 };
             }
@@ -475,8 +486,8 @@ sub lint_prereqs {
                     error   => "Only used in test phase but listed under runtime prereq in dist.ini",
                     remedy  => "Move prereq from runtime to test prereq in dist.ini",
                     remedy_cmds => [
-                        ["pdrutil", "remove-prereq", $mod],
-                        ["pdrutil", "add-prereq", $mod, $v, "--phase", "test"],
+                        ["pdrutil", "remove-prereq", $mod0],
+                        ["pdrutil", "add-prereq", $mod0, $v, "--phase", "test"],
                     ],
                 };
             }
@@ -490,8 +501,8 @@ sub lint_prereqs {
                     error   => "Used in runtime phase but listed only under test prereq in dist.ini",
                     remedy  => "Move prereq from test to runtime prereq in dist.ini",
                     remedy_cmds => [
-                        ["pdrutil", "remove-prereq", $mod],
-                        ["pdrutil", "add-prereq", $mod, $v],
+                        ["pdrutil", "remove-prereq", $mod0],
+                        ["pdrutil", "add-prereq", $mod0, $v],
                     ],
                 };
             }
@@ -503,7 +514,7 @@ sub lint_prereqs {
                     error   => "Unused but listed in dist.ini",
                     remedy  => "Remove from dist.ini",
                     remedy_cmds => [
-                        ["pdrutil", "remove-prereq", $mod],
+                        ["pdrutil", "remove-prereq", $mod0],
                     ],
                 };
             }
@@ -545,6 +556,7 @@ sub lint_prereqs {
     {
         for my $mod (keys %{$mods_from_scanned{Any}}) {
             next if $mod eq 'perl';
+            my $mod0 = ($extrarels{$mod} // '') . $mod;
             my $v = $mods_from_scanned{Any}{$mod};
             $log->tracef("Checking mod from scanned: %s (%s)", $mod, $v);
             my $is_core = Module::CoreList::More->is_still_core($mod, $v, $perlv);
@@ -569,7 +581,7 @@ sub lint_prereqs {
                     error   => "Used but not listed in dist.ini",
                     remedy  => "Put '$mod=$v' in dist.ini (e.g. in [Prereqs/${phase}Requires])",
                     remedy_cmds => [
-                        ["pdrutil", "add-prereq", $mod, $v, "--phase", lc($phase)],
+                        ["pdrutil", "add-prereq", $mod0, $v, "--phase", lc($phase)],
                     ],
                 };
             }
@@ -582,6 +594,7 @@ sub lint_prereqs {
         $log->tracef("Checking minimum versions ...");
         for my $mod (keys %{$mods_from_ini{Any}}) {
             next if $mod eq 'perl';
+            my $mod0 = ($extrarels{$mod} // '') . $mod;
             my $v = $mods_from_ini{Any}{$mod};
             my $is_core = Module::CoreList::More->is_still_core($mod, $v, $perlv);
             my $min_v = $versions->{$mod};
@@ -593,7 +606,7 @@ sub lint_prereqs {
                     error   => "Less than specified minimum version ($min_v) in lint-prereqs.conf",
                     remedy  => "Increase version to $min_v",
                     remedy_cmds => [
-                        ["pdrutil", "inc-prereq-version-to", $mod, $min_v],
+                        ["pdrutil", "inc-prereq-version-to", $mod0, $min_v],
                     ],
                 };
             }
@@ -671,7 +684,7 @@ App::LintPrereqs - Check extraneous/missing/incorrect prerequisites in dist.ini
 
 =head1 VERSION
 
-This document describes version 0.49 of App::LintPrereqs (from Perl distribution App-LintPrereqs), released on 2016-12-27.
+This document describes version 0.50 of App::LintPrereqs (from Perl distribution App-LintPrereqs), released on 2016-12-27.
 
 =head1 SYNOPSIS
 
